'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var mplTokenMetadata = require('@metaplex-foundation/mpl-token-metadata');
var pdas = require('./pdas.cjs');
var Creator = require('../../types/Creator.cjs');
var Operation = require('../../types/Operation.cjs');
var TransactionBuilder = require('../../utils/TransactionBuilder.cjs');

// -----------------
// Operation
// -----------------
const Key = 'AddMetadataOperation';
const addMetadataOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const addMetadataOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const builder = await addMetadataBuilder(metaplex, operation.input);
    scope.throwIfCanceled();
    return builder.sendAndConfirm(metaplex, operation.input.confirmOptions);
  }
}; // -----------------
// Builder
// -----------------

const addMetadataBuilder = (metaplex, params) => {
  var _params$creators, _params$symbol, _params$collection, _params$uses, _params$isMutable, _params$createMetadat;

  const {
    mint,
    payer = metaplex.identity(),
    updateAuthority = metaplex.identity().publicKey,
    mintAuthority = metaplex.identity()
  } = params;
  const metadataPda = pdas.findMetadataPda(mint);
  const creators = (_params$creators = params.creators) !== null && _params$creators !== void 0 ? _params$creators : Creator.toUniformVerifiedCreators(mintAuthority.publicKey);
  return TransactionBuilder.TransactionBuilder.make().setFeePayer(payer).setContext({
    metadataAddress: metadataPda
  }) // Create metadata account.
  .add({
    instruction: mplTokenMetadata.createCreateMetadataAccountV2Instruction({
      metadata: metadataPda,
      mint,
      mintAuthority: mintAuthority.publicKey,
      payer: payer.publicKey,
      updateAuthority: updateAuthority
    }, {
      createMetadataAccountArgsV2: {
        data: {
          name: params.name,
          symbol: (_params$symbol = params.symbol) !== null && _params$symbol !== void 0 ? _params$symbol : '',
          uri: params.uri,
          sellerFeeBasisPoints: params.sellerFeeBasisPoints,
          creators,
          collection: (_params$collection = params.collection) !== null && _params$collection !== void 0 ? _params$collection : null,
          uses: (_params$uses = params.uses) !== null && _params$uses !== void 0 ? _params$uses : null
        },
        isMutable: (_params$isMutable = params.isMutable) !== null && _params$isMutable !== void 0 ? _params$isMutable : true
      }
    }),
    signers: [payer, mintAuthority],
    key: (_params$createMetadat = params.createMetadataInstructionKey) !== null && _params$createMetadat !== void 0 ? _params$createMetadat : 'createMetadata'
  });
};

exports.addMetadataBuilder = addMetadataBuilder;
exports.addMetadataOperation = addMetadataOperation;
exports.addMetadataOperationHandler = addMetadataOperationHandler;
//# sourceMappingURL=addMetadata.cjs.map
