import { createCreateMetadataAccountV2Instruction } from '@metaplex-foundation/mpl-token-metadata';
import { findMetadataPda } from './pdas.mjs';
import { toUniformVerifiedCreators } from '../../types/Creator.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { TransactionBuilder } from '../../utils/TransactionBuilder.mjs';

// -----------------
// Operation
// -----------------
const Key = 'AddMetadataOperation';
const addMetadataOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const addMetadataOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const builder = await addMetadataBuilder(metaplex, operation.input);
    scope.throwIfCanceled();
    return builder.sendAndConfirm(metaplex, operation.input.confirmOptions);
  }
}; // -----------------
// Builder
// -----------------

const addMetadataBuilder = (metaplex, params) => {
  var _params$creators, _params$symbol, _params$collection, _params$uses, _params$isMutable, _params$createMetadat;

  const {
    mint,
    payer = metaplex.identity(),
    updateAuthority = metaplex.identity().publicKey,
    mintAuthority = metaplex.identity()
  } = params;
  const metadataPda = findMetadataPda(mint);
  const creators = (_params$creators = params.creators) !== null && _params$creators !== void 0 ? _params$creators : toUniformVerifiedCreators(mintAuthority.publicKey);
  return TransactionBuilder.make().setFeePayer(payer).setContext({
    metadataAddress: metadataPda
  }) // Create metadata account.
  .add({
    instruction: createCreateMetadataAccountV2Instruction({
      metadata: metadataPda,
      mint,
      mintAuthority: mintAuthority.publicKey,
      payer: payer.publicKey,
      updateAuthority: updateAuthority
    }, {
      createMetadataAccountArgsV2: {
        data: {
          name: params.name,
          symbol: (_params$symbol = params.symbol) !== null && _params$symbol !== void 0 ? _params$symbol : '',
          uri: params.uri,
          sellerFeeBasisPoints: params.sellerFeeBasisPoints,
          creators,
          collection: (_params$collection = params.collection) !== null && _params$collection !== void 0 ? _params$collection : null,
          uses: (_params$uses = params.uses) !== null && _params$uses !== void 0 ? _params$uses : null
        },
        isMutable: (_params$isMutable = params.isMutable) !== null && _params$isMutable !== void 0 ? _params$isMutable : true
      }
    }),
    signers: [payer, mintAuthority],
    key: (_params$createMetadat = params.createMetadataInstructionKey) !== null && _params$createMetadat !== void 0 ? _params$createMetadat : 'createMetadata'
  });
};

export { addMetadataBuilder, addMetadataOperation, addMetadataOperationHandler };
//# sourceMappingURL=addMetadata.mjs.map
